@@ -100,7 +100,7 @@ func (reader *Reader) preAllocLines(originalFileName string) {
 	}
 }
 
-// This function will be update the Reader struct in the background.
+// This function will update the Reader struct in the background.
 func (reader *Reader) readStream(stream io.Reader, originalFileName *string, onDone func()) {
 	defer func() {
 		reader.done.Store(true)
@@ -191,11 +191,13 @@ func (reader *Reader) readStream(stream io.Reader, originalFileName *string, onD
 	default:
 	}
 
-	if onDone != nil {
-		onDone()
-	}
-
 	log.Debug("Stream read in ", time.Since(t0))
+
+	if onDone != nil {
+		t1 := time.Now()
+		onDone()
+		log.Debug("onDone() took ", time.Since(t1))
+	}
 }
 
 // Note that you must call reader.SetStyleForHighlighting() after this to get
@@ -331,7 +333,7 @@ func countLines(filename string) (uint64, error) {
 	const lineBreak = '\n'
 	sliceWithSingleLineBreak := []byte{lineBreak}
 
-	reader, err := ZOpen(filename)
+	reader, _, err := ZOpen(filename)
 	if err != nil {
 		return 0, err
 	}
@@ -384,21 +386,24 @@ func NewReaderFromFilenameWithoutStyle(filename string, formatter chroma.Formatt
 		return nil, fileError
 	}
 
-	stream, err := ZOpen(filename)
+	stream, highlightingFilename, err := ZOpen(filename)
 	if err != nil {
 		return nil, err
 	}
 
-	// Set lexer to nil in this call since we want to do our own highlighting in
-	// parallel with the stream being read. See the call to
-	// StartHighlightingFromFile() below.
-	returnMe := newReaderFromStream(stream, &filename, nil, nil)
+	if lexer == nil {
+		lexer = lexers.Match(highlightingFilename)
+	}
+
+	returnMe := newReaderFromStream(stream, &filename, formatter, lexer)
 
 	returnMe.Lock()
 	returnMe.name = &filename
 	returnMe.Unlock()
 
-	startHighlightingFromFile(returnMe, filename, formatter, lexer)
+	if lexer == nil {
+		returnMe.highlightingDone.Store(true)
+	}
 
 	return returnMe, nil
 }
@@ -419,58 +424,6 @@ func NewReaderFromFilename(filename string, style chroma.Style, formatter chroma
 	return mReader, nil
 }
 
-func startHighlightingFromFile(reader *Reader, filename string, formatter chroma.Formatter, lexer chroma.Lexer) {
-	reportDone := func() {
-		reader.highlightingDone.Store(true)
-		select {
-		case reader.maybeDone <- true:
-		default:
-		}
-
-		log.Trace("Highlighting done")
-	}
-
-	fileInfo, err := os.Stat(filename)
-	if err != nil {
-		log.Warn("Failed to stat file for highlighting: ", err)
-		reportDone()
-		return
-	}
-	if fileInfo.Size() > MAX_HIGHLIGHT_SIZE {
-		log.Debug("File too large for highlighting: ", fileInfo.Size())
-		reportDone()
-		return
-	}
-
-	go func() {
-		defer reportDone()
-
-		fileBytes, err := os.ReadFile(filename)
-		if err != nil {
-			log.Warn("Failed to read file for highlighting: ", err)
-			return
-		}
-
-		if lexer == nil {
-			// Try auto detecting by filename
-			lexer = lexers.Match(filename)
-		}
-
-		highlighted, err := highlight(string(fileBytes), <-reader.highlightingStyle, formatter, lexer)
-		if err != nil {
-			log.Warn("Highlighting failed: ", err)
-			return
-		}
-
-		if highlighted == nil {
-			// No highlighting would be done, never mind
-			return
-		}
-
-		reader.setText(*highlighted)
-	}()
-}
-
 // We expect this to be executed in a goroutine
 func highlightFromMemory(reader *Reader, style chroma.Style, formatter chroma.Formatter, lexer chroma.Lexer) {
 	if lexer == nil {
