@@ -710,7 +710,7 @@ func pagerFromArgs(
 		return nil, nil, chroma.Style{}, nil, nil
 	}
 
-	var style chroma.Style
+	var style chroma.Style = *styles.Get(defaultDarkTheme)
 	if *styleOption == nil {
 		t0 := time.Now()
 		screen.RequestTerminalBackgroundColor()
@@ -744,6 +744,7 @@ func pagerFromArgs(
 	} else {
 		style = **styleOption
 	}
+	log.Debug("Using style <", style.Name, ">")
 	reader.SetStyleForHighlighting(style)
 
 	pager := m.NewPager(reader)
